@@ -31,7 +31,7 @@ version = ''
 # The full version, including alpha/beta/rc tags.
 release = ''
 try:
-    from cirq_iqm import __version__ as version
+    from iqm.cirq_iqm import __version__ as version
 except ImportError:
     pass
 else:
@@ -91,6 +91,8 @@ autoclass_content = 'both'
 # Sphinx 3.3+: manually clean up type alias rendering in the docs
 # autodoc_type_aliases = {'TypeAlias': 'exa.experiment.somemodule.TypeAlias'}
 
+# This is required to make docs build work after the client packages were moved to iqm namespace.
+autodoc_mock_imports = ["iqm_client"]
 
 # -- Autosummary ------------------------------------------------------------
 
@@ -110,9 +112,7 @@ html_theme = 'sphinx_book_theme'
 # Add any paths that contain custom themes here, relative to this directory.
 html_theme_path = [sphinx_book_theme.get_html_theme_path()]
 
-html_context = dict(
-    display_github=False
-)
+html_context = dict(display_github=False)
 
 # Theme options are theme-specific and customize the look and feel of a theme
 # further.  For a list of options available for each theme, see the
@@ -121,11 +121,7 @@ html_theme_options = {
     'logo_only': True,
 }
 
-html_sidebars = {
-    '**': [
-        'sidebar-logo.html', 'search-field.html', 'sbt-sidebar-nav.html', 'versioning.html'
-    ]
-}
+html_sidebars = {'**': ['sidebar-logo.html', 'search-field.html', 'sbt-sidebar-nav.html', 'versioning.html']}
 
 # A shorter title for the navigation bar.  Default is the same as html_title.
 # html_short_title = None
@@ -186,14 +182,14 @@ extlinks = {
 # -- Options for sphinxcontrib.bibtex -------------------------------------------------
 
 # List of all bibliography files used.
-#bibtex_bibfiles = ['references.bib']
+# bibtex_bibfiles = ['references.bib']
 
 # -- Options for sphinx_multiversion --------------------------------------------------
 # Only include certain tags (i.e. all tags except for ones listed below)
 # (technically a whitelist, but we treat it as blacklist by using negative lookahead regex `?!`)
 smv_tag_whitelist = r'^(?!([0-3]\.[0-9]*)).*$'  # ignore all the versions before 4.0
 
-smv_branch_whitelist = "None"   # Do not include local branches in versions list
-smv_remote_whitelist = "None"   # Do not include remote branches in versions list
+smv_branch_whitelist = "None"  # Do not include local branches in versions list
+smv_remote_whitelist = "None"  # Do not include remote branches in versions list
 smv_released_pattern = r'^refs/tags/.*$'  # Tags recognized as releases
 smv_outputdir_format = 'versions/{ref.name}'  # Store versioned docs in a subdirectory
